@@ -1,25 +1,15 @@
 /*
-    Copyright 2007-2008 Fela Winkelmolen <fela.kde@gmail.com>
+    SPDX-FileCopyrightText: 2007-2008 Fela Winkelmolen <fela.kde@gmail.com>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "gameengine.h"
 
+// own
 #include "kbreakout_debug.h"
 #include "levelloader.h"
-
+// Qt
 #include <QTimer>
 #include <QTime>
 
@@ -42,7 +32,7 @@ void GameEngine::start(const QString &l)
     m_levelLoader->setLevelset(l);
     m_levelLoader->setLevel(0);
 
-    emit loadingNewGame();
+    Q_EMIT loadingNewGame();
 
     loadLevel();
 }
@@ -53,7 +43,7 @@ void GameEngine::loadLevel()
 
     m_levelLoader->loadLevel();
 
-    emit ready();
+    Q_EMIT ready();
 }
 
 void GameEngine::loadNextLevel()
