@@ -1,31 +1,22 @@
 /*
-    Copyright 2011 Julian Helfferich <julian.helfferich@gmail.com>
+    SPDX-FileCopyrightText: 2011 Julian Helfferich <julian.helfferich@gmail.com>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "levelloader.h"
+
+// own
 #include "globals.h"
 #include "kbreakout_debug.h"
-
-#include <QDomDocument>
-#include <QFile>
-#include <QStandardPaths>
-
+// KF
 // These can be removed when KConfig style levelsets are no longer supported
 #include <KConfig>
 #include <KConfigGroup>
+// Qt
+#include <QDomDocument>
+#include <QFile>
+#include <QStandardPaths>
 
 LevelLoader::LevelLoader(QObject *parent)
     : QObject(parent)
@@ -193,7 +184,7 @@ void LevelLoader::loadLine(QDomElement lineNode)
                                       << m_lineNumber;
     }
 
-    emit newLine(line, m_lineNumber);
+    Q_EMIT newLine(line, m_lineNumber);
 }
 
 void LevelLoader::loadGift(QDomElement giftNode)
@@ -246,7 +237,7 @@ void LevelLoader::loadGift(QDomElement giftNode)
         }
     }
 
-    emit newGift(giftType, times, position);
+    Q_EMIT newGift(giftType, times, position);
 }
 
 void LevelLoader::loadOldStyleLevel()
@@ -288,7 +279,7 @@ void LevelLoader::loadOldStyleLevel()
             qCCritical(KBREAKOUT_General) << "Invalid file: too many bricks\n";
         }
 
-        emit newLine(line, y);
+        Q_EMIT newLine(line, y);
 
         ++y;
         key = QLatin1String("line") + QString::number(y);
@@ -314,6 +305,6 @@ void LevelLoader::loadOldStyleLevel()
             continue;
         }
 
-        emit newGift(key, times, QString());
+        Q_EMIT newGift(key, times, QString());
     }
 }
